import { db } from './config';
import { collection, addDoc, deleteDoc, updateDoc, doc, getDocs, query, where, setDoc, getDoc } from 'firebase/firestore';
import type { Store, GroceryItem } from '@/types';

// Store Operations
export const fetchStores = async (userId: string): Promise<Store[]> => {
  const storesRef = collection(db, 'stores');
  const q = query(storesRef, where('userId', '==', userId));
  const snapshot = await getDocs(q);
  
  return snapshot.docs.map(doc => ({
    id: doc.id,
    ...doc.data() as Omit<Store, 'id'>
  }));
};

export const addStore = async (store: Omit<Store, 'id'>) => {
  return await addDoc(collection(db, 'stores'), store);
};

export const deleteStore = async (storeId: string) => {
  await deleteDoc(doc(db, 'stores', storeId));
};

// Item Operations
export const fetchItems = async (userId: string): Promise<GroceryItem[]> => {
  const itemsRef = collection(db, 'items');
  const q = query(itemsRef, where('userId', '==', userId));
  const snapshot = await getDocs(q);
  
  return snapshot.docs.map(doc => ({
    id: doc.id,
    ...doc.data() as Omit<GroceryItem, 'id'>
  }));
};

export const addItem = async (item: Omit<GroceryItem, 'id'>) => {
  return await addDoc(collection(db, 'items'), item);
};

export const updateItem = async (id: string, data: Partial<GroceryItem>) => {
  await updateDoc(doc(db, 'items', id), data);
};

export const deleteItem = async (itemId: string) => {
  await deleteDoc(doc(db, 'items', itemId));
}; 